==> embla-carousel-4.5.3.tgz: package/README.md <==
<br />
<div align="center">
  <p align="center">
    <a href="https://www.embla-carousel.com/"><img width="70" height="70" src="https://www.embla-carousel.com/embla-logo.svg" alt="Embla Carousel">
    </a>
  </p>

  <p align="center">
    <a href="https://opensource.org/licenses/MIT"><img src="https://img.shields.io/npm/l/embla-carousel?color=%238ab4f8"></a>
    <a href="https://www.npmjs.com/package/embla-carousel"><img src="https://img.shields.io/npm/v/embla-carousel.svg?color=%23c1a8e2"></a>
    <a href="https://github.com/davidcetinkaya/embla-carousel/actions?query=workflow%3A%22Continuous+Integration%22"><img src="https://img.shields.io/github/workflow/status/davidcetinkaya/embla-carousel/Continuous%20Integration?color=%238ab4f8"></a>
    <a href="https://prettier.io"><img src="https://img.shields.io/badge/code_style-prettier-ff69b4.svg?style=flat&color=%23c1a8e2"></a>
    <a href="https://bundlephobia.com/result?p=embla-carousel@latest"><img src="https://img.shields.io/bundlephobia/minzip/embla-carousel?color=%238ab4f8&label=gzip%20size">
    </a>
  </p>

  <strong>
    <h2 align="center">Embla Carousel</h2>
  </strong>

  <p align="center">
    <a href="https://www.embla-carousel.com/">Embla Carousel</a> is a bare bones carousel library with great fluid motion and awesome swipe precision. It's library agnostic, dependency free and 100% open source. Build awesome carousels by extending Embla Carousel with your own CSS and JavaScript.
  </p>

  <br>

  <p align="center">
    <strong>
      <code>&nbsp;<a href="https://www.embla-carousel.com/get-started/#choose-installation-type">Installation</a>&nbsp;</code>
    </strong>
  </p>

  <p align="center">
    <strong>
      <code>&nbsp;<a href="https://www.embla-carousel.com/api/">API Reference</a>&nbsp;</code>
    </strong>
  </p>

  <p align="center">
    <strong>
      <code>&nbsp;<a href="https://www.embla-carousel.com/examples/basic/">Examples</a>&nbsp;</code>
    </strong>
  </p>
</div>

<br>

<div align="center">
  <strong>
    <h2 align="center">Platforms</h2>
  </strong>
  <p align="center">
    <a href="https://www.embla-carousel.com/">Embla Carousel</a> is ready to use with the following tools/libraries.
  </p>
  <p align="center">
    <a href="https://www.embla-carousel.com/get-started/module/">
      <img src="https://www.embla-carousel.com/javascript-logo.svg" width="45" height="45" />
    </a>
    &nbsp;
    <a href="https://www.embla-carousel.com/get-started/module/">
      <img src="https://www.embla-carousel.com/typescript-logo.svg" width="45" height="45" />
    </a>
    &nbsp;
    <a href="https://www.embla-carousel.com/get-started/react/">
      <img src="https://www.embla-carousel.com/react-logo.svg" width="45" height="45" />
    </a>
  </p>
</div>

<br>

<div align="center">
  <strong>
    <h2 align="center">Contributors</h2>
  </strong>
  <p align="center">
    Thank you to all contributors for making <a href="https://www.embla-carousel.com/">Embla Carousel</a> awesome! <a href="https://github.com/davidcetinkaya/embla-carousel/blob/master/.github/CONTRIBUTING.md">Contributions</a> are welcome.
  </p>
  <p align="center">
    <a href="https://github.com/nikrowell"><img src="https://avatars2.githubusercontent.com/u/260039?s=120&v=4" title="nikrowell" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/michaelrambeau"><img src="https://avatars0.githubusercontent.com/u/5546996?s=120&v=4" title="michaelrambeau" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/ehellman"><img src="https://avatars3.githubusercontent.com/u/586152?s=120&v=4" title="ehellman" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/afilp"><img src="https://avatars0.githubusercontent.com/u/7850073?s=120&v=4" title="afilp" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/mrksmts"><img src="https://avatars1.githubusercontent.com/u/437794?s=120&v=4" title="mrksmts" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/SLMNBJ"><img src="https://avatars2.githubusercontent.com/u/30017004?s=120&v=4" title="SLMNBJ" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/readeral"><img src="https://avatars0.githubusercontent.com/u/15904136?s=120&v=4" title="readeral" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/romellem"><img src="https://avatars2.githubusercontent.com/u/8504000?s=120&v=4" title="romellem" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/niubsta"><img src="https://avatars0.githubusercontent.com/u/270320?s=120&v=4" title="niubsta" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/allen-garvey"><img src="https://avatars1.githubusercontent.com/u/9314727?s=120s&v=4" title="allen-garvey" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/sedlukha"><img src="https://avatars3.githubusercontent.com/u/14075940?s=120&v=4" title="sedlukha" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/wopian"><img src="https://avatars3.githubusercontent.com/u/3440094?s=120&v=4" title="wopian" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/msallent"><img src="https://avatars3.githubusercontent.com/u/8879212?s=120&v=4" title="msallent" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/omarkhatibco"><img src="https://avatars1.githubusercontent.com/u/9054278?s=120&v=4" title="omarkhatibco" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/ppromerojr"><img src="https://avatars1.githubusercontent.com/u/15343254?s=120&v=4" title="ppromerojr" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/openscript"><img src="https://avatars3.githubusercontent.com/u/1105080?s=120&v=4" title="openscript" width="60" height="60" style="max-width:100%;"></a>

  </p>
</div>

<br>

<div align="center">
  <strong>
    <h2 align="center">Special Thanks</h2>
  </strong>
  <p align="center">
    Massive thanks to <a href="https://github.com/gunnarx2">gunnarx2</a> for creating the <a href="https://www.embla-carousel.com/get-started/react/">useEmblaCarousel </a> hook and to <a href="https://github.com/xiel">xiel</a> for creating the <a href="https://github.com/xiel/embla-carousel-wheel-gestures">Embla Carousel Wheel Gestures</a> package.
  </p>
  <p align="center">
    <a href="https://github.com/gunnarx2"><img src="https://avatars2.githubusercontent.com/u/10469652?s=120&v=4" title="gunnarx2" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/xiel"><img src="https://avatars0.githubusercontent.com/u/615522?s=120&v=4" title="xiel" width="60" height="60" style="max-width:100%;"></a>
  </p>
</div>

<br>

<h2 align="center">Open Source</h2>

<p align="center">
  <sup>Copyright © 2019-present, David Cetinkaya.</sup><br>
  Embla is <a href="https://github.com/davidcetinkaya/embla-carousel/blob/master/LICENSE">MIT licensed</a> 💖.
</p>

<p align="center">
  <strong>· · ·</strong>
</p>

<p align="center">
  Thanks <a href="https://www.browserstack.com">BrowserStack</a>.
</p>

<p align="center">
  <a href="https://www.browserstack.com">
    <img src="https://www.embla-carousel.com/browserstack-logo.svg" width="45" height="45" />
    </a>
</p>

==> embla-carousel-7.1.0.tgz: package/README.md <==
<br />
<div align="center">
  <p align="center">
    <a href="https://www.embla-carousel.com/"><img width="100" height="100" src="https://www.embla-carousel.com/embla-logo.svg" alt="Embla Carousel">
    </a>
  </p>

  <p align="center">
    <a href="https://opensource.org/licenses/MIT"><img src="https://img.shields.io/npm/l/embla-carousel?color=%238ab4f8"></a>
    <a href="https://www.npmjs.com/package/embla-carousel"><img src="https://img.shields.io/npm/v/embla-carousel.svg?color=%23c1a8e2"></a>
    <a href="https://github.com/davidjerleke/embla-carousel/actions?query=workflow%3A%22Continuous+Integration%22"><img src="https://img.shields.io/github/actions/workflow/status/davidjerleke/embla-carousel/cd.yml?color=%238ab4f8"></a>
    <a href="https://prettier.io"><img src="https://img.shields.io/badge/code_style-prettier-ff69b4.svg?style=flat&color=%23c1a8e2"></a>
    <a href="https://bundlephobia.com/result?p=embla-carousel@latest"><img src="https://img.shields.io/bundlephobia/minzip/embla-carousel?color=%238ab4f8&label=gzip%20size">
    </a>
  </p>

  <strong>
    <h2 align="center">Embla Carousel</h2>
  </strong>

  <p align="center">
    <a href="https://www.embla-carousel.com/">Embla Carousel</a> is a bare bones carousel library with great fluid motion and awesome swipe precision. It's library agnostic, dependency free and 100% open source. Build awesome carousels by extending Embla Carousel with your own CSS and JavaScript.
  </p>

  <br>

  <p align="center">
    <strong>
      <code>&nbsp;<a href="https://www.embla-carousel.com/get-started/#choose-installation-type">Installation</a>&nbsp;</code>
    </strong>
  </p>

  <p align="center">
    <strong>
      <code>&nbsp;<a href="https://www.embla-carousel.com/api/">API Reference</a>&nbsp;</code>
    </strong>
  </p>

  <p align="center">
    <strong>
      <code>&nbsp;<a href="https://www.embla-carousel.com/examples/static/">Examples</a>&nbsp;</code>
    </strong>
  </p>
</div>

<br>

<div align="center">
  <strong>
    <h2 align="center">Platforms</h2>
  </strong>
  <p align="center">
    <a href="https://www.embla-carousel.com/">Embla Carousel</a> is ready to use with the following tools/libraries.
  </p>
  <p align="center">
    <a href="https://www.embla-carousel.com/get-started/module/">
      <img src="https://www.embla-carousel.com/javascript-logo.svg" width="45" height="45" />
    </a>
    &nbsp;
    <a href="https://www.embla-carousel.com/get-started/module/">
      <img src="https://www.embla-carousel.com/typescript-logo.svg" width="45" height="45" />
    </a>
    &nbsp;
    <a href="https://www.embla-carousel.com/get-started/react/">
      <img src="https://www.embla-carousel.com/react-logo.svg" width="45" height="45" />
    </a>
  </p>
</div>

<br>

<div align="center">
  <strong>
    <h2 align="center">Contributors</h2>
  </strong>
  <p align="center">
    Thank you to all contributors for making <a href="https://www.embla-carousel.com/">Embla Carousel</a> awesome! <a href="https://github.com/davidjerleke/embla-carousel/blob/master/.github/CONTRIBUTING.md">Contributions</a> are welcome.
  </p>
  <p align="center">
    <a href="https://github.com/nikrowell"><img src="https://avatars2.githubusercontent.com/u/260039?s=120&v=4" title="nikrowell" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/michaelrambeau"><img src="https://avatars0.githubusercontent.com/u/5546996?s=120&v=4" title="michaelrambeau" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/ehellman"><img src="https://avatars3.githubusercontent.com/u/586152?s=120&v=4" title="ehellman" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/afilp"><img src="https://avatars0.githubusercontent.com/u/7850073?s=120&v=4" title="afilp" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/mrksmts"><img src="https://avatars1.githubusercontent.com/u/437794?s=120&v=4" title="mrksmts" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/SLMNBJ"><img src="https://avatars2.githubusercontent.com/u/30017004?s=120&v=4" title="SLMNBJ" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/readeral"><img src="https://avatars0.githubusercontent.com/u/15904136?s=120&v=4" title="readeral" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/romellem"><img src="https://avatars2.githubusercontent.com/u/8504000?s=120&v=4" title="romellem" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/niubsta"><img src="https://avatars0.githubusercontent.com/u/270320?s=120&v=4" title="niubsta" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/allen-garvey"><img src="https://avatars1.githubusercontent.com/u/9314727?s=120s&v=4" title="allen-garvey" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/sedlukha"><img src="https://avatars3.githubusercontent.com/u/14075940?s=120&v=4" title="sedlukha" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/wopian"><img src="https://avatars3.githubusercontent.com/u/3440094?s=120&v=4" title="wopian" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/msallent"><img src="https://avatars3.githubusercontent.com/u/8879212?s=120&v=4" title="msallent" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/omarkhatibco"><img src="https://avatars1.githubusercontent.com/u/9054278?s=120&v=4" title="omarkhatibco" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/ppromerojr"><img src="https://avatars1.githubusercontent.com/u/15343254?s=120&v=4" title="ppromerojr" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/openscript"><img src="https://avatars3.githubusercontent.com/u/1105080?s=120&v=4" title="openscript" width="60" height="60" style="max-width:100%;"></a>

  </p>
</div>

<br>

<div align="center">
  <strong>
    <h2 align="center">Special Thanks</h2>
  </strong>
  <p align="center">
    Massive thanks to <a href="https://github.com/gunnarx2">gunnarx2</a> for creating the <a href="https://www.embla-carousel.com/get-started/react/">useEmblaCarousel </a> hook and to <a href="https://github.com/xiel">xiel</a> for creating the <a href="https://github.com/xiel/embla-carousel-wheel-gestures">Embla Carousel Wheel Gestures</a> package.
  </p>
  <p align="center">
    <a href="https://github.com/gunnarx2"><img src="https://avatars2.githubusercontent.com/u/10469652?s=120&v=4" title="gunnarx2" width="60" height="60" style="max-width:100%;"></a>
    <a href="https://github.com/xiel"><img src="https://avatars0.githubusercontent.com/u/615522?s=120&v=4" title="xiel" width="60" height="60" style="max-width:100%;"></a>
  </p>
</div>

<br>

<h2 align="center">Open Source</h2>

<p align="center">
  <sup>Copyright © 2019-present, David Jerleke.</sup><br>
  Embla is <a href="https://github.com/davidjerleke/embla-carousel/blob/master/LICENSE">MIT licensed</a> 💖.
</p>

<p align="center">
  <strong>· · ·</strong>
</p>

<p align="center">
  Thanks <a href="https://www.browserstack.com">BrowserStack</a>.
</p>

<p align="center">
  <a href="https://www.browserstack.com">
    <img src="https://www.embla-carousel.com/browserstack-logo.svg" width="45" height="45" />
    </a>
</p>
